jupyter_server: The backend (core services, APIs, REST endpoints) to Jupyter web applications
=============================================================================================

Description
-----------

The backend, i.e., core services, APIs, and REST endpoints, to Jupyter web applications.

License
-------

BSD 3-Clause License

Upstream Contact
----------------

https://pypi.org/project/jupyter-server/

